package com.siit.wfw.frame.utils;

import com.alibaba.fastjson.JSONObject;
import com.siit.wfw.frame.utils.ConfigUtils;
import com.siit.wfw.frame.utils.MD5Util;
import com.siit.wfw.frame.utils.SpringContextUtils;
import com.siit.wfw.frame.utils.http.FileEntity;
import com.siit.wfw.frame.utils.http.HttpClient;
import com.siit.wfw.frame.utils.http.HttpResult;
import java.io.File;
import java.io.FileInputStream;
import java.time.Instant;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import org.apache.commons.io.IOUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class SearchImageUtil {

   private static final Logger logger = LoggerFactory.getLogger(SearchImageUtil.class);
   private static SearchImageUtil instance = new SearchImageUtil();
   private static final String PUSH_IMAGE_LIBRARY_URL = "/siitapi/imagesearch/add/v1";
   private static final String SEARCH_IMAGE_LIBRARY_URL = "/siitapi/imagesearch/search/v1";
   private static final String CAN_SEARCH_TYPE = "jpg,jpeg,png";
   @Autowired
   private ConfigUtils configUtils;


   public static String pushImageLibrary(String filename, byte[] fileBytes) {
      return instance.doPostImageLibrary("/siitapi/imagesearch/add/v1", filename, fileBytes);
   }

   public static String searchImageLibrary(String filename, byte[] fileBytes) {
      return instance.doPostImageLibrary("/siitapi/imagesearch/search/v1", filename, fileBytes);
   }

   public String getConfig(String key) {
      if(this.configUtils == null) {
         this.configUtils = (ConfigUtils)SpringContextUtils.getApplication().getBean("configUtils");
      }

      return this.configUtils.getConfig(key);
   }

   private String doPostImageLibrary(String url, String filename, byte[] fileBytes) {
      try {
         String e = filename.substring(filename.lastIndexOf(".") + 1).toLowerCase(Locale.ROOT);
         if(!"jpg,jpeg,png".contains(e)) {
            return "";
         } else {
            String[] configs = instance.getConfig("IMAGE_LIBRARY_CONFIG").split(";");
            String urlPrefix = configs[0];
            String user_key = configs[1];
            String private_key = configs[2];
            ArrayList fileEntities = new ArrayList();
            fileEntities.add(new FileEntity(filename, filename, fileBytes));
            long timestamp = Instant.now().getEpochSecond();
            JSONObject paramJson = new JSONObject();
            paramJson.put("user_key", user_key);
            paramJson.put("timestamp", Long.valueOf(timestamp));
            paramJson.put("data", new JSONObject());
            paramJson.put("token", MD5Util.getStringMD5(user_key + private_key + timestamp));
            paramJson.put("app_id", "siitcams");
            HashMap param = new HashMap();
            param.put("param", paramJson.toJSONString());
            HttpResult httpResult = HttpClient.httpPost(urlPrefix + url, param, (Map)null, fileEntities, "", "UTF-8");
            if(httpResult.getStatusCode() != 200) {
               logger.error("调用搜图库异常！");
               return "";
            } else {
               JSONObject result = JSONObject.parseObject(new String(httpResult.getContent(), "UTF-8"));
               if(!result.containsKey("data")) {
                  logger.error("调用搜图库返回异常！返回：" + result);
                  return "";
               } else {
                  JSONObject data = result.getJSONObject("data");
                  if(!data.containsKey("result")) {
                     logger.error("调用搜图库返回异常！返回：" + result);
                     return "";
                  } else {
                     return data.getJSONObject("result").getString("file_id");
                  }
               }
            }
         }
      } catch (Exception var17) {
         var17.printStackTrace();
         logger.error("调用搜图库返回异常！", var17);
         return "";
      }
   }

   public static void main(String[] args) throws Exception {
      long timestamp = Instant.now().getEpochSecond();
      JSONObject paramJson = new JSONObject();
      paramJson.put("user_key", "1");
      paramJson.put("timestamp", Long.valueOf(timestamp));
      paramJson.put("data", new JSONObject());
      paramJson.put("token", MD5Util.getStringMD5("11" + timestamp));
      paramJson.put("app_id", "siitcams");
      JSONObject addJSOn = new JSONObject();
      File[] tests = (new File("E:\\app\\")).listFiles();

      for(int i = 0; i < tests.length; ++i) {
         String filename = tests[i].getName();
         ArrayList fileEntities = new ArrayList();
         fileEntities.add(new FileEntity(filename, filename, IOUtils.toByteArray(new FileInputStream(tests[i]))));
         HashMap param = new HashMap();
         param.put("param", paramJson.toJSONString());
         HttpResult httpResult = HttpClient.httpPost("http://192.168.0.206:9012/siitapi/imagesearch/search/v1", param, (Map)null, fileEntities, "", "UTF-8");
         if(httpResult.getStatusCode() != 200) {
            logger.error("调用搜图库异常！");
            return;
         }

         JSONObject result = JSONObject.parseObject(new String(httpResult.getContent(), "UTF-8"));
         if(!result.containsKey("data")) {
            logger.error("调用搜图库返回异常！返回：" + result);
            return;
         }

         JSONObject data = result.getJSONObject("data");
         if(!data.containsKey("result")) {
            logger.error("调用搜图库返回异常！返回：" + result);
            return;
         }

         String fileId = data.getJSONObject("result").getString("file_id");
         addJSOn.put(filename, fileId);
      }

      System.out.println(addJSOn);
   }

}
